==> news-feed-1.0.0-20130521.032530-16-sources.jar: org/gcube/portlets/user/newsfeed/shared/UserSettings.java <==
package org.gcube.portlets.user.newsfeed.shared;

import java.io.Serializable;

import org.gcube.portal.databook.shared.UserInfo;

@SuppressWarnings("serial")
public class UserSettings implements Serializable {
	private UserInfo userInfo;
	private int refreshingTimeInMillis;
	private String currentScope;
	boolean isInfrastructure;
	public UserSettings() { 
		super();
	}
	public UserSettings(UserInfo userInfo, int refreshingTimeInMillis,
			String currentScope, boolean isInfrastructure) {
		super();
		this.userInfo = userInfo;
		this.refreshingTimeInMillis = refreshingTimeInMillis;
		this.currentScope = currentScope;
		this.isInfrastructure = isInfrastructure;
	}
	public UserInfo getUserInfo() {
		return userInfo;
	}
	public void setUserInfo(UserInfo userInfo) {
		this.userInfo = userInfo;
	}
	public int getRefreshingTimeInMillis() {
		return refreshingTimeInMillis;
	}
	public void setRefreshingTimeInMillis(int refreshingTimeInMillis) {
		this.refreshingTimeInMillis = refreshingTimeInMillis;
	}
	public String getCurrentScope() {
		return currentScope;
	}
	public void setCurrentScope(String currentScope) {
		this.currentScope = currentScope;
	}
	public boolean isInfrastructure() {
		return isInfrastructure;
	}
	public void setInfrastructure(boolean isInfrastructure) {
		this.isInfrastructure = isInfrastructure;
	}
	@Override
	public String toString() {
		return "UserSettings [userInfo=" + userInfo
				+ ", refreshingTimeInMillis=" + refreshingTimeInMillis
				+ ", currentScope=" + currentScope + ", isInfrastructure="
				+ isInfrastructure + "]";
	}
	
}

==> news-feed-1.5.0-20140319.184450-1-sources.jar: org/gcube/portlets/user/newsfeed/shared/UserSettings.java <==
package org.gcube.portlets.user.newsfeed.shared;

import java.io.Serializable;

import org.gcube.portal.databook.shared.UserInfo;

@SuppressWarnings("serial")
public class UserSettings implements Serializable {
	private UserInfo userInfo;
	private int refreshingTimeInMillis;
	private String currentScope;
	private String channelName;
	boolean isInfrastructure;
	public UserSettings() { 
		super();
	}

	public UserSettings(UserInfo userInfo, int refreshingTimeInMillis,
			String currentScope, String channelName, boolean isInfrastructure) {
		super();
		this.userInfo = userInfo;
		this.refreshingTimeInMillis = refreshingTimeInMillis;
		this.currentScope = currentScope;
		this.channelName = channelName;
		this.isInfrastructure = isInfrastructure;
	}

	public UserInfo getUserInfo() {
		return userInfo;
	}
	public void setUserInfo(UserInfo userInfo) {
		this.userInfo = userInfo;
	}
	public int getRefreshingTimeInMillis() {
		return refreshingTimeInMillis;
	}
	public void setRefreshingTimeInMillis(int refreshingTimeInMillis) {
		this.refreshingTimeInMillis = refreshingTimeInMillis;
	}
	public String getCurrentScope() {
		return currentScope;
	}
	public void setCurrentScope(String currentScope) {
		this.currentScope = currentScope;
	}
	public boolean isInfrastructure() {
		return isInfrastructure;
	}
	public void setInfrastructure(boolean isInfrastructure) {
		this.isInfrastructure = isInfrastructure;
	}
	
	public String getChannelName() {
		return channelName;
	}

	public void setChannelName(String channelName) {
		this.channelName = channelName;
	}

	@Override
	public String toString() {
		return "UserSettings [userInfo=" + userInfo
				+ ", refreshingTimeInMillis=" + refreshingTimeInMillis
				+ ", currentScope=" + currentScope + ", isInfrastructure="
				+ isInfrastructure + "]";
	}
	
}
